@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2020-2024, by Samuel Williams.
+# Copyright, 2020-2025, by Samuel Williams.
 
 require "samovar"
 
@@ -29,7 +29,11 @@ module Bake
 			def call
 				context = @parent.context
 				
-				context.call(*@commands)
+				context.call(*@commands) do |recipe, last_result|
+					if last_result and !recipe.output?
+						context.lookup("output").call(input: last_result)
+					end
+				end
 			end
 		end
 	end
